#
# spec file for package python-coconut
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
# coconut is a programming language, not a python module
%define pythons python3
Name:           python-coconut
Version:        1.6.0
Release:        1.7
Summary:        A functional programming language that compiles to Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/evhub/coconut
Source:         https://files.pythonhosted.org/packages/source/c/coconut/coconut-%{version}.tar.gz
BuildRequires:  %{python_module Pygments >= 2.2}
BuildRequires:  %{python_module prompt_toolkit >= 2}
BuildRequires:  %{python_module pyparsing >= 2.2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pygments >= 2.2
Requires:       python-prompt_toolkit >= 2
Requires:       python-pyparsing >= 2.2
Recommends:     python-cPyparsing >= 2.2.0.1.1
Recommends:     python-ipykernel >= 4.6
Recommends:     python-ipython >= 5.4
Recommends:     python-jupyter >= 1
Recommends:     python-jupyter_console >= 5.2
Recommends:     python-mypy >= 0.540
Recommends:     python-psutil >= 5
Recommends:     python-requests >= 2
Recommends:     python-watchdog >= 0.8
Conflicts:      python2-coconut <= 1.4.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module cPyparsing >= 2.2.0.1.1}
BuildRequires:  %{python_module ipykernel >= 4.6}
BuildRequires:  %{python_module ipython >= 5.4}
BuildRequires:  %{python_module jupyter >= 1}
BuildRequires:  %{python_module jupyter_console >= 5.2}
BuildRequires:  %{python_module mypy >= 0.540}
BuildRequires:  %{python_module psutil >= 5}
BuildRequires:  %{python_module pytest >= 3}
BuildRequires:  %{python_module requests >= 2}
BuildRequires:  %{python_module watchdog >= 0.8}
# /SECTION
%python_subpackages

%description
Coconut is a functional programming language that compiles to
Python. Since all valid Python is valid Coconut, using Coconut will
only extend and enhance what is already capable of in Python.

Coconut enhances the repertoire of Python programmers to include
tools for functional programming. Coconut code runs the same on any
Python version.

%prep
%setup -q -n coconut-%{version}
find . -type f -exec sed -i 's/\r$//' {} +
find . -name '*.py' -exec sed -i -e '/^#!\//, 1d' {} +

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}/%{$python_sitelib}/
# a hint how to package it welcome
rm %{buildroot}/usr/share/jupyter/kernels/coconut/kernel.json

%files %{python_files}
%doc README.rst CONTRIBUTING.md DOCS.md FAQ.md HELP.md
%license LICENSE.txt
%{_bindir}/coconut-py3*
%{_bindir}/coconut
%{_bindir}/coconut-v1*
%{_bindir}/coconut-release*
%{_bindir}/coconut-run
%{python_sitelib}/coconut/
%{python_sitelib}/coconut-%{version}-py*.egg-info

%changelog
* Tue Sep 20 2022 pgajdos@suse.com
- version update to 1.6.0
  * https://github.com/evhub/coconut/releases/tag/v1.6.0
- does not require six
* Thu Feb 18 2021 Dirk Müller <dmueller@suse.com>
- skip multi-version build, this is a compiler not a python module
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.1:
  * add support for python 3.8
* Fri May 24 2019 Todd R <toddrme2178@gmail.com>
- Add conflicts with python2 version since we are dropping
  update-alternatives.
* Wed May 22 2019 Todd R <toddrme2178@gmail.com>
- Drop python2 support since some of its dependencies have also
  dropped python2 support.
- Use new jupyter package names.
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Oct  7 2018 Todd R <toddrme2178@gmail.com>
- Fix conflict with IPython dependencies.
  The python2 version of IPython requires prompt_toolkit 1 while
  the python3 version requires prompt_toolkit 2.
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Update to 1.4.0
  * #320: added import hook to automatically compile imported Coconut files (thanks @ArneBachmann!)
  * #347: added where clauses
  * #270: added a memoize decorator (thanks @iamrecursion!)
  * #403: added a TYPE_CHECKING constant
  * #409: added support for M `bind` x -> y syntax
  * #419: data type equality is now typed (thanks everyone in #418!)
  * #331: support negative pattern-matching with match ... not in ...
  * #411: count now supports a step size of 0
  * #394: scan now has an initializer argument
  * #398: creating a new indented block after a colon is no longer necessary for any statement
  * #229: --strict now warns on unused imports
  * #327: interpreter now supports reload built-in (thanks, @ArneBachmann!)
  * #382: interpreter now supports compiling to arbitrary file names
  * #393: unicode operators for multiplication and matrix multiplication have been switched
  * #153: function composition precedence is now such that f..g(x) is the same as f..(g(x)) not (f..g)(x)
  * #395: built-in attributes changed to remove initial underscores
* Sun Jun 10 2018 jengelh@inai.de
- Fix repeated name in summary (rpmlint).
- Trim rhetoric parts from description.
- Use find "+" logic.
* Thu May 24 2018 toddrme2178@gmail.com
- Fix dependencies
* Thu Dec  7 2017 sleep_walker@opensuse.org
- take package from home:geewass:python
- rewrite to cleanup, use singlespec
